diff --git a/htdocs/langs/en_US/admin.lang b/htdocs/langs/en_US/admin.lang
index 3df2a8fc72da5d37e73c5c69e3c642f66e8fe2a9..f10c6ebbb3a9fbac1cf5b0ecd126d1dc11c9e5a0 100755
--- a/htdocs/langs/en_US/admin.lang
+++ b/htdocs/langs/en_US/admin.lang
@@ -495,7 +495,7 @@ Module1780Name=Categories
 Module1780Desc=Category management (products, suppliers and customers)
 Module2000Name=WYSIWYG editor
 Module2000Desc=Allow to edit some text area using an advanced editor
-Module2200Name=Dinamic Prices
+Module2200Name=Dynamic Prices
 Module2200Desc=Enable the usage of math expressions for prices
 Module2300Name=Cron
 Module2300Desc=Scheduled task management
diff --git a/htdocs/product/fournisseurs.php b/htdocs/product/fournisseurs.php
index b0d07587996988f1d48f81c681583f4c803b75de..864ac162ea9136c39f37a54e6b59f04b88ffbc95 100755
--- a/htdocs/product/fournisseurs.php
+++ b/htdocs/product/fournisseurs.php
@@ -196,7 +196,7 @@ if ($action == 'updateprice' && GETPOST('cancel') <> $langs->trans("Cancel"))
 						setEventMessage($priceparser->translated_error(), 'errors');
 					}
 				}
-				if (! $error && ! empty($conf->dinamicprices->enabled)) {
+				if (! $error && ! empty($conf->dynamicprices->enabled)) {
 					$ret=$product->set_price_expression($price_expression);
 					if ($ret < 0)
 					{
@@ -399,7 +399,7 @@ if ($id || $ref)
 				print '<input type="text" class="flat" size="5" name="tva_tx" value="'.(GETPOST("tva_tx")?vatrate(GETPOST("tva_tx")):($default_vat!=''?vatrate($default_vat):'')).'">';
 				print '</td></tr>';
 
-				if (! empty($conf->dinamicprices->enabled)) { //Only show price mode and expression selector if module is enabled
+				if (! empty($conf->dynamicprices->enabled)) { //Only show price mode and expression selector if module is enabled
 					// Price mode selector
 					print '<tr><td class="fieldrequired">'.$langs->trans("PriceMode").'</td><td>';
 					$price_expression = new PriceExpression($db);
diff --git a/htdocs/core/modules/modDinamicPrices.class.php b/htdocs/core/modules/modDinamicPrices.class.php
index 392fc1bae52afc069f804f76d81856a90f8917a5..c1450bc3b27695e6912e9c211c227717c4386654 100755
--- a/htdocs/core/modules/modDinamicPrices.class.php
+++ b/htdocs/core/modules/modDinamicPrices.class.php
@@ -16,19 +16,19 @@
  */
 
 /**
  *  \defgroup   produit     Module dinamic prices
  *  \brief      Module to manage dinamic prices in products
  *  \file       htdocs/core/modules/modDinamicPrices.class.php
  *  \ingroup    produit
  *  \brief      File to describe module to manage dinamic prices in products
  */
 include_once DOL_DOCUMENT_ROOT .'/core/modules/DolibarrModules.class.php';
 
 
 /**
  *  Class descriptor of DinamicPrices module
  */
-class modDinamicPrices extends DolibarrModules
+class modDynamicPrices extends DolibarrModules
 {
 
     /**
@@ -58,7 +58,7 @@ class modDinamicPrices extends DolibarrModules
 
         // Config pages
         //-------------
-        //$this->config_page_url = array("dinamicprices.php@dinamicprices");
+        //$this->config_page_url = array("dynamicprices.php@dynamicprices");
 
         // Dependancies
         //-------------
@@ -81,7 +81,7 @@ class modDinamicPrices extends DolibarrModules
         // Permissions
         //------------
         $this->rights = array();
-        $this->rights_class = 'dinamicprices';
+        $this->rights_class = 'dynamicprices';
         $r=0;
     }
 
@@ -16,19 +16,19 @@
 
 /**
- *  \defgroup   produit     Module dinamic prices
- *  \brief      Module to manage dinamic prices in products
- *  \file       htdocs/core/modules/modDinamicPrices.class.php
+ *  \defgroup   produit     Module dynamic prices
+ *  \brief      Module to manage dynamic prices in products
+ *  \file       htdocs/core/modules/modDynamicPrices.class.php
  *  \ingroup    produit
@@ -16,19 +16,19 @@
  *  \ingroup    produit
- *  \brief      File to describe module to manage dinamic prices in products
+ *  \brief      File to describe module to manage dynamic prices in products
  */
 include_once DOL_DOCUMENT_ROOT .'/core/modules/DolibarrModules.class.php';
@@ -16,19 +16,19 @@
 
 /**
- *  Class descriptor of DinamicPrices module
+ *  Class descriptor of DynamicPrices module
  */